@@ -47,10 +47,17 @@ class DiscreteEnv(gym.Env):
     self.max_Xas=np.array([np.float32(self.maxXa1), np.float32(self.maxXs1)])
     
     
+    #set ACTION SPACE
+    self.row = np.linspace(-2, 2, 50).tolist()
+    self.action_space = spaces.Tuple((
+      spaces.Discrete(50),
+      spaces.Discrete(50),
+      spaces.Discrete(50)))
    
+    
     #set ACTION SPACE
     #discrete 0, 1
-    self.action_space = spaces.Discrete(n=2)
+    #self.action_space = spaces.Discrete(n=2)
     
     #set OBSERVATION SPACE
     #it is made of values for Xa, Xs for each observation
@@ -77,6 +84,11 @@ class DiscreteEnv(gym.Env):
   #it returns the next observation, the immediate reward, whether the episode is over (done) and additional information    
   #"action" argument is one value in the range of the action space (logit transform)
   def step(self, action): 
+    
+    
+    #recover action value using indexes from onerow
+    action0, action1, action2 = action
+    action_0, action_1, action_2 = self.onerow[action0], self.onerow[action1], self.onerow[action2]   
 
       
     data = []
@@ -84,12 +96,24 @@ class DiscreteEnv(gym.Env):
       Xs = self.state[0]
       Xa = self.state[1]
       Y = self.state[2]
-      Xsa=(self.thetasa[0])+(self.thetasa[1])*(Xs)+(self.thetasa[2])*(Xa)
+      
+      #### old bit
+      #Xsa=(self.thetasa[0])+(self.thetasa[1])*(Xs)+(self.thetasa[2])*(Xa)
+      #rho2 = (1/(1+np.exp(-Xsa)))  #prob of Y=1
+      #g2 = ((Xa) + 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*(1-rho2) + ((Xa) - 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*rho2
+      #if (rho2>0.2) or (action == 1):
+       # Xa=g2
+      #else: Xa=Xa 
+      #### end old bit
+      
+      
+      Xsa=(action_0)+(action_1)*(Xs)+(action_2)*(Xa)
       rho2 = (1/(1+np.exp(-Xsa)))  #prob of Y=1
       g2 = ((Xa) + 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*(1-rho2) + ((Xa) - 0.5*((Xa)+math.sqrt(1+(Xa)**2)))*rho2
-      if (rho2>0.2) or (action == 1):
+      if (rho2>0.2):
         Xa=g2
-      else: Xa=Xa 
+      else: Xa=Xa     
+      
 
       data.append([Xs, Xa, Y])
 
